@@ -1,4 +1,4 @@
-/*	$Id: priv.h,v 1.6 2001/12/22 03:41:12 riq Exp $	*/
+/*	$Id: priv.h,v 1.11 2002/10/13 23:29:08 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -23,15 +23,27 @@
 #define __TEG_GUI_GNOME_PRIV_H
 
 #include <gnome.h>
+#include <gconf/gconf-client.h>
+
+enum {
+	DIALOG_ATTACK_TURN,
+	DIALOG_REGROUP_ARMIES,
+	DIALOG_PLACE_ARMIES
+};
 
 struct _gui_private {
 	int tag;
+	int tag_ggz;
 	BOOLEAN msg_show_colors;
-	unsigned int status_show;
+	unsigned int status_show;	/* what columns to show in the status window */
+	unsigned int dialog_show;	/* what dialogs to show */
+	int country_i_am;		/* what country i'm pointing */
 };
 
 extern struct _gui_private gui_private;
 
+extern GConfClient *g_conf_client;
+
 TEG_STATUS priv_init( void );
 
 #endif /* __TEG_GUI_GNOME_PRIV_H */
