@@ -1,4 +1,4 @@
-/*	$Id: main.c,v 1.20 2001/11/10 18:56:35 riq Exp $	*/
+/*	$Id: main.c,v 1.25 2002/09/07 19:25:56 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -27,17 +27,13 @@
 
 #include "client.h"
 
-#ifdef WITH_GGZ
-#include "ggz_client.h"
-#endif /* WITH_GGZ */
-
-
 TEG_STATUS main_init()
 {
-	juego_init();
-	g_juego.human = 1;
-	jugador_init();
+	game_init();
+	g_game.human = 1;
+	player_init();
 	scores_init();
+	metaserver_init();
 	return TEG_STATUS_SUCCESS;
 }
 
@@ -45,7 +41,6 @@ int main( int argc, char **argv)
 {
 	int i;
 
-	init_nls();
 	dont_run_as_root();
 
 	i = 1;
@@ -57,15 +52,7 @@ int main( int argc, char **argv)
 		exit(-1);
 	}
 
-#ifdef WITH_GGZ
-	if( g_juego.with_ggz) ggz_client_init("teg");
-#endif /* WITH_GGZ */
-
 	gui_main();
 
-#ifdef WITH_GGZ
-	if( g_juego.with_ggz) ggz_client_quit();
-#endif /* WITH_GGZ */
-
 	return 1;
 }
