@@ -1,4 +1,4 @@
-/*	$Id: server.h,v 1.12 2001/09/03 00:55:40 riq Exp $	*/
+/*	$Id: server.h,v 1.17 2002/10/14 01:25:04 riq Exp $	*/
 /* Tenes Empanadas Graciela
  *
  * Copyright (C) 2000 Ricardo Quesada
@@ -29,18 +29,19 @@
 #include "all.h"
 
 #include "tarjeta.h"
-#include "paises.h"
-#include "jugador.h"
+#include "countries.h"
+#include "player.h"
 #include "turno.h"
 #include "globals.h"
 #include "sernet.h"
 #include "protocol.h"
 #include "play.h"
 #include "console.h"
-#include "aux.h"
+#include "helper.h"
 #include "main.h"
-#include "objetivos.h"
-#include "tegggz.h"
+#include "missions.h"
+#include "ggz_server.h"
 #include "options.h"
+#include "metaserver.h"
 
 #endif /* __TEGS_SERVER_H */
